@@ -1,7 +1,8 @@
-call_praznik = function(self, task, fun) {
+call_praznik = function(self, task, fun, nfeat) {
   selection = invoke(fun,
     X = task$data(cols = task$feature_names),
     Y = task$truth(),
+    k = nfeat,
     .args = self$param_set$get_values()
   )$selection
 
